# hy015removed

[![Build Status](https://img.shields.io/travis/niitsuma/hy015removedl/master.svg?style=flat-square)](https://travis-ci.org/niitsuma/hy015removed)
[![Downloads](https://pepy.tech/badge/hy015removedb)](https://pepy.tech/project/hy015removedb)
[![Version](https://img.shields.io/pypi/v/hy015removed.svg?style=flat-square)](https://pypi.python.org/pypi/hy015removed)


compat functions removed in hy-lang ver0.15 for hy 0.18


# implemented function list 
- list-comp 
- set-comp 
- dict-comp 
